<?php

namespace App\Http\Controllers\API;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\User;
use App\Models\PasswordReset;
use Hash;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Validator;
use App\Http\Resources\API\UserResource;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Str;
use App\Mail\OTPMail;
use Illuminate\Database\QueryException;


class LoginController extends Controller
{

    public function login(Request $request)
    {
        $request->validate([
            'email' => 'required|string|email',
            'password' => 'required|string',
        ]);

      if(Auth::attempt(['email'=>$request->email,'password'=>$request->password]))
      {
        $user = Auth::user();
        return response()->json([
            'user' => UserResource::make($user),
            'message' => 'Logged in successfully',
            'authorization' => [
                'token' => $user->createToken('MyApp')->accessToken,
                'type' => 'bearer',
            ]
        ]);
      }

      return response()->json([
                'message' => 'Mismatch',
            ], 401);
    }

    public function register(Request $request)
    {
        $validator=Validator::make($request->all(),[
        'first_name'=>'required',
        'last_name'=>'required',
        'avatar'=>'required',
        'email'=>'required',
        'gender'=>'required',
        'phone'=>'required',
        'password'=>'required'
        ]);

        if($validator->fails())
        {
            return response()->json($validator->errors(),200);
        }
        $input=$request->all();
        $input['password']=bcrypt($input['password']);
        if($request->hasFile('avatar')) {
            $file = $request->file('avatar');
            $ext = $file->getClientOriginalExtension();
            $name = asset("avatar_images/img-" . time() . "-" . rand() . "." . $ext); // Generate a unique file name
            $destinationPath = public_path('avatar_images');
            $file->move($destinationPath, $name);
            $input['avatar'] = $name;
        }
        //dd($input);
        $user=User::create($input);
        $responseArray=[];
        $reponseArray['token']=$user->createToken('MyApp')->accessToken;
        $reponseArray['first_name']=$user->first_name;
        return response()->json($reponseArray,202);

    }


   
   
    public function refresh(Request $request)
    {
        $user = $request->user();
        $token = $user->createToken('AppName')->accessToken;

        return response()->json(['access_token' => $token]);
    }



// Change Password  Api //
    public function change_password(Request $request)
    {
        $validator= Validator::make($request->all(),[
        'old_password'=>'required',
        'password'=>'required|max:8',
        'confirm_password'=>'required|same:password',
        'otp' => 'required|size:6'

        ]);
        if($validator->fails())
        {
            return response()->json([
                'message'=>'Validation Fails',
                'message' => $validator->errors()


            ],422);
        }
        $user=$request->user();
        $passwordReset=PasswordReset::where('email',$user->email)->first();
        if (!$passwordReset || !Hash::check($request->otp, $passwordReset->token)) {
            return response()->json([
                'message' => 'Invalid OTP',
            ], 400);
        }
        if(Hash::check($request->old_password,$user->password))
        {
            $user->update([
                'password'=>Hash::make($request->password)


            ]);
            $passwordReset->delete();
            return response()->json([
                'message'=>'Password Succesfully Update'

            ],200);
        }else{
            return response()->json([
                'message'=>'Old password does not matched'

            ],400);

        }
    }


// send otp code to  Email//

public function send_otp_code(Request $request)
{
    $request->validate([
        'email' => 'required|email',
    ]);

    $user = User::where('email', $request->email)->first();
    if (!$user) {
        return response()->json(['message' => 'User not found'], 404);
    }

    // Generate OTP CODE
    $otp = Str::random(6);

    try {
        $passwordReset = PasswordReset::updateOrCreate(
            ['email' => $user->email],
            ['token' => Hash::make($otp), 'created_at' => now()]
        );

        Mail::to($user->email)->send(new OTPMail($otp));

        return response()->json(['message' => 'OTP sent to your email']);
    } catch (\Exception $e) {
        \Log::error($e->getMessage());
        return response()->json(['message' => 'An error occurred while updating the token'], 500);
    }
}


  }



