<?php

namespace App\Models;

use App\Models\User;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Factories\HasFactory;

class Application extends Model
{
    use HasFactory;

     /** APPLICATION TYPES */
     public const TYPE_STUDY_VISA = 'Study Visa';
     public const TYPE_GENERAL_IMMIGRATION = 'General Immigration';
     public const TYPE_PERMANENT_RESIDENCY = 'Permanent Residency';
     public const TYPE_WORK_VISA = 'Work Visa';


     /** ALL APPLICATION TYPES */
     public const ALL_APPLICATION_TYPES = [
         self::TYPE_STUDY_VISA,
         self::TYPE_GENERAL_IMMIGRATION,
         self::TYPE_PERMANENT_RESIDENCY,
         self::TYPE_WORK_VISA,
     ];


     /**
     * The attributes that are mass assignable.
     *
     * @var array<int, string>
     */
    protected $fillable = [
        'user_id',
        'type',
        'current_country',
        'marital_status',
        'age',
        'past_educational_institute',
        'education',
        'ielts_completed',
        'ielts_score',
        'work_experience',
        'crs_score',
        'year_to_move_in',
        'family_in_country',
        'education_to_pursue',
        'consultation_needed',
        'medically_effected',
        'sufficient_fund',
        'need_loan_assistance',
        'job_to_pursue'

    ];


     /**
     * The attributes that should be cast.
     *
     * @var array<string, string>
     */
    protected $casts = [
        'ielts_completed' => 'boolean',
        'family_in_country' => 'boolean',
        'consultation_needed' => 'boolean',
        'medically_effected' => 'boolean',
        'sufficient_fund' => 'boolean',
        'need_loan_assistance' => 'boolean',
        'valid_eca' => 'boolean',
    ];

    /*
    |--------------------------------------------------------------------------
    | RELATIONS
    |--------------------------------------------------------------------------
    */

    /**
     * user
     *
     * @return BelongsTo
     */
    public function user(): BelongsTo
     {
         return $this->belongsTo(
             User::class,
             'user_id',
             'id',
         );
     }



    /*
    |--------------------------------------------------------------------------
    | FUNCTIONS
    |--------------------------------------------------------------------------
    */
}
